==> libsocialweb-0.25.9.tar.gz: libsocialweb-0.25.9/libsocialweb/sw-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "sw-enum-types.h"

/* enumerations from "./sw-service.h" */
#include "./sw-service.h"

GType
sw_service_error_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SW_SERVICE_ERROR_NO_KEYS, "SW_SERVICE_ERROR_NO_KEYS", "no-keys" },
        { SW_SERVICE_ERROR_INVALID_QUERY, "SW_SERVICE_ERROR_INVALID_QUERY", "invalid-query" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SwServiceError"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./sw-debug.h" */
#include "./sw-debug.h"

GType
sw_debug_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { SW_DEBUG_MAIN_LOOP, "SW_DEBUG_MAIN_LOOP", "main-loop" },
        { SW_DEBUG_VIEWS, "SW_DEBUG_VIEWS", "views" },
        { SW_DEBUG_ONLINE, "SW_DEBUG_ONLINE", "online" },
        { SW_DEBUG_ITEM, "SW_DEBUG_ITEM", "item" },
        { SW_DEBUG_TWITTER, "SW_DEBUG_TWITTER", "twitter" },
        { SW_DEBUG_LASTFM, "SW_DEBUG_LASTFM", "lastfm" },
        { SW_DEBUG_CORE, "SW_DEBUG_CORE", "core" },
        { SW_DEBUG_VIMEO, "SW_DEBUG_VIMEO", "vimeo" },
        { SW_DEBUG_FLICKR, "SW_DEBUG_FLICKR", "flickr" },
        { SW_DEBUG_CLIENT_MONITOR, "SW_DEBUG_CLIENT_MONITOR", "client-monitor" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("SwDebugFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* Generated data ends here */

==> libsocialweb-0.25.13.tar.gz: libsocialweb-0.25.13/libsocialweb/sw-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "sw-enum-types.h"

/* enumerations from "./sw-service.h" */
#include "./sw-service.h"

GType
sw_service_error_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { SW_SERVICE_ERROR_NO_KEYS, "SW_SERVICE_ERROR_NO_KEYS", "NoKeys" },
        { SW_SERVICE_ERROR_INVALID_QUERY, "SW_SERVICE_ERROR_INVALID_QUERY", "InvalidQuery" },
        { SW_SERVICE_ERROR_NOT_SUPPORTED, "SW_SERVICE_ERROR_NOT_SUPPORTED", "NotSupported" },
        { SW_SERVICE_ERROR_REMOTE_ERROR, "SW_SERVICE_ERROR_REMOTE_ERROR", "RemoteError" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("SwServiceError"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./sw-debug.h" */
#include "./sw-debug.h"

GType
sw_debug_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { SW_DEBUG_MAIN_LOOP, "SW_DEBUG_MAIN_LOOP", "main-loop" },
        { SW_DEBUG_VIEWS, "SW_DEBUG_VIEWS", "views" },
        { SW_DEBUG_ONLINE, "SW_DEBUG_ONLINE", "online" },
        { SW_DEBUG_ITEM, "SW_DEBUG_ITEM", "item" },
        { SW_DEBUG_TWITTER, "SW_DEBUG_TWITTER", "twitter" },
        { SW_DEBUG_LASTFM, "SW_DEBUG_LASTFM", "lastfm" },
        { SW_DEBUG_CORE, "SW_DEBUG_CORE", "core" },
        { SW_DEBUG_VIMEO, "SW_DEBUG_VIMEO", "vimeo" },
        { SW_DEBUG_FLICKR, "SW_DEBUG_FLICKR", "flickr" },
        { SW_DEBUG_SMUGMUG, "SW_DEBUG_SMUGMUG", "smugmug" },
        { SW_DEBUG_PHOTOBUCKET, "SW_DEBUG_PHOTOBUCKET", "photobucket" },
        { SW_DEBUG_CLIENT_MONITOR, "SW_DEBUG_CLIENT_MONITOR", "client-monitor" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("SwDebugFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* Generated data ends here */
